This folder contains example scripts demonstrating whylogs usage.

If you're new to whylogs and want to get your hands dirty, check out the [Getting Started](./basic/Getting_Started.ipynb) Notebook under the `basics` folder!

If you're willing to learn more how to use and get going with whylogs, take a look at our sections:

- Basic - The fundamentals of whylogs
  - [Visualizing Profiles](./basic/Notebook_Profile_Visualizer.ipynb) - Compare profiles to detect distribution shifts, visualize histograms and bar charts and explore your data
  - [Logging Data](./basic/Logging_Different_Data.ipynb) - See the different ways you can log your data with whylogs
  - [Inspecting Profiles](./basic/Inspecting_Profiles.ipynb) - A deeper dive on the metrics generated by whylogs
  - [Schema Configuration for Tracking Metrics](./basic/Schema_Configuration.ipynb) - Configure tracking metrics according to data type or column features
  - [Data Constraints](./basic/Metric_Constraints.ipynb) - Set constraints to your data to ensure its quality
  - [Merging Profiles](./basic/Merging_Profiles.ipynb) - Merge your profiles logged across different computing instances, time periods or data segments
- Advanced - Customize and use whylogs in complex scenarios
  - [Streaming Data with Log Rotation](./advanced/Log_Rotation_for_Streaming_Data/Streaming_Data_with_Log_Rotation.ipynb) - Generate profiles automatically at fixed intervals with rolling loggers
  - [Condition Count Metrics](./advanced/Condition_Count_Metrics.ipynb) - Create simple counter metrics with user-defined conditions
  - [Constraints Suite](./advanced/Constraints_Suite.ipynb) - A collection of simple out-of-the-box constraints for the most common use-cases
  - [Custom Metrics](./advanced/Custom_Metrics.ipynb) - Create your own metrics and metric components
  - [String Tracking](./advanced/String_Tracking.ipynb) - Track unicode ranges and character length distribution metrics for your textual features
- Integrations - Use whylogs with external platforms
  - [Pyspark](./integrations/Pyspark_Profiling.ipynb) - Use whylogs with pyspark
  - [Writing Profiles](./integrations/writers/Writing_Profiles.ipynb) - See different ways and locations to output your profiles
  - [Flask](./integrations/flask_streaming/flask_with_whylogs.ipynb) - See how you can create a Flask app with whylogs and WhyLabs integration
  - [Feature Stores](./integrations/Feature_Stores_and_whylogs.ipynb) - Learn how to log features from your Feature Store with feast and whylogs
  - [BigQuery](./integrations/BigQuery_Example.ipynb) - Profile data queried from a Google BigQuery table
  - [MLflow](./integrations/Mlflow_Logging.ipynb) - Log your whylogs profiles to an MLflow environment
  - WhyLabs - Monitor your profiles continuously with the WhyLabs Observability Platform
    - [WhyLabs](./integrations/writers/Writing_to_WhyLabs.ipynb) - Send profiles to your WhyLabs Dashboard
    - [WhyLabs - Reference Profile](./integrations/writers/Writing_Reference_Profiles_to_WhyLabs.ipynb) - Send profiles as Reference (Static) Profiles to WhyLabs

The examples in this folder can also be viewed in whylogs' documentation in https://whylogs.readthedocs.io/en/latest/
